MODEL_DETAIL = {
    "YDN1600": {"name": "Yardian", "zones": 12},
    "YDN1602": {"name": "Yardian", "zones": 8},
    "PRO1600": {"name": "Yardian Pro", "zones": 12},
    "PRO1602": {"name": "Yardian Pro", "zones": 8},
    "PRO1900": {"name": "Yardian Pro", "zones": 12},
    "PRO1902": {"name": "Yardian Pro", "zones": 8},
    "PRO1906": {"name": "Yardian Pro", "zones": 6},
    "PRO1900C1": {"name": "Yardian Pro C1", "zones": 12},
    "PRO1902C1": {"name": "Yardian Pro C1", "zones": 8},
    "PRO1906C1": {"name": "Yardian Pro C1", "zones": 6},
}

DEFAULT_TIMEOUT = 30